@@ -4,10 +4,9 @@
 #include "modules/bios/bios.h"
 #include "util/stringUtils.h"
 
-#define FF_BIOS_NUM_FORMAT_ARGS 5
-
-void ffPrintBios(FFBiosOptions* options)
+bool ffPrintBios(FFBiosOptions* options)
 {
+    bool success = false;
     FFBiosResult bios;
     ffStrbufInit(&bios.date);
     ffStrbufInit(&bios.release);
@@ -43,14 +42,15 @@ void ffPrintBios(FFBiosOptions* options)
     else
     {
         ffStrbufClear(&key);
-        FF_PARSE_FORMAT_STRING_CHECKED(&key, &options->moduleArgs.key, 1, ((FFformatarg[]){
-            {FF_FORMAT_ARG_TYPE_STRBUF, &bios.type},
+        FF_PARSE_FORMAT_STRING_CHECKED(&key, &options->moduleArgs.key, ((FFformatarg[]) {
+            FF_FORMAT_ARG(bios.type, "type"),
+            FF_FORMAT_ARG(options->moduleArgs.keyIcon, "icon"),
         }));
     }
 
     if(options->moduleArgs.outputFormat.length == 0)
     {
-        ffPrintLogoAndKey(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
+        ffPrintLogoAndKey(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY);
         ffStrbufWriteTo(&bios.version, stdout);
         if (bios.release.length)
             printf(" (%s)\n", bios.release.chars);
@@ -59,14 +59,15 @@ void ffPrintBios(FFBiosOptions* options)
     }
     else
     {
-        FF_PRINT_FORMAT_CHECKED(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_BIOS_NUM_FORMAT_ARGS, ((FFformatarg[]) {
-            {FF_FORMAT_ARG_TYPE_STRBUF, &bios.date},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &bios.release},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &bios.vendor},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &bios.version},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &bios.type},
+        FF_PRINT_FORMAT_CHECKED(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY, ((FFformatarg[]) {
+            FF_FORMAT_ARG(bios.date, "date"),
+            FF_FORMAT_ARG(bios.release, "release"),
+            FF_FORMAT_ARG(bios.vendor, "vendor"),
+            FF_FORMAT_ARG(bios.version, "version"),
+            FF_FORMAT_ARG(bios.type, "type"),
         }));
     }
+    success = true;
 
 exit:
     ffStrbufDestroy(&bios.date);
@@ -74,45 +75,31 @@ exit:
     ffStrbufDestroy(&bios.vendor);
     ffStrbufDestroy(&bios.version);
     ffStrbufDestroy(&bios.type);
-}
 
-bool ffParseBiosCommandOptions(FFBiosOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_BIOS_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    return false;
+    return success;
 }
 
 void ffParseBiosJsonObject(FFBiosOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        ffPrintError(FF_BIOS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_BIOS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateBiosJsonConfig(FFBiosOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyBiosOptions))) FFBiosOptions defaultOptions;
-    ffInitBiosOptions(&defaultOptions);
-
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 }
 
-void ffGenerateBiosJsonResult(FF_MAYBE_UNUSED FFBiosOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateBiosJsonResult(FF_MAYBE_UNUSED FFBiosOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
+    bool success = false;
     FFBiosResult bios;
     ffStrbufInit(&bios.date);
     ffStrbufInit(&bios.release);
@@ -128,18 +115,13 @@ void ffGenerateBiosJsonResult(FF_MAYBE_UNUSED FFBiosOptions* options, yyjson_mut
         goto exit;
     }
 
-    if (bios.version.length == 0)
-    {
-        yyjson_mut_obj_add_str(doc, module, "error", "bios_version is not set.");
-        goto exit;
-    }
-
     yyjson_mut_val* obj = yyjson_mut_obj_add_obj(doc, module, "result");
     yyjson_mut_obj_add_strbuf(doc, obj, "date", &bios.date);
     yyjson_mut_obj_add_strbuf(doc, obj, "release", &bios.release);
     yyjson_mut_obj_add_strbuf(doc, obj, "vendor", &bios.vendor);
     yyjson_mut_obj_add_strbuf(doc, obj, "version", &bios.version);
     yyjson_mut_obj_add_strbuf(doc, obj, "type", &bios.type);
+    success = true;
 
 exit:
     ffStrbufDestroy(&bios.date);
@@ -147,36 +129,33 @@ exit:
     ffStrbufDestroy(&bios.vendor);
     ffStrbufDestroy(&bios.version);
     ffStrbufDestroy(&bios.type);
-}
-
-void ffPrintBiosHelpFormat(void)
-{
-    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_BIOS_MODULE_NAME, "{4} ({2})", FF_BIOS_NUM_FORMAT_ARGS, ((const char* []) {
-        "bios date",
-        "bios release",
-        "bios vendor",
-        "bios version",
-        "firmware type",
-    }));
+    return success;
 }
 
 void ffInitBiosOptions(FFBiosOptions* options)
 {
-    ffOptionInitModuleBaseInfo(
-        &options->moduleInfo,
-        FF_BIOS_MODULE_NAME,
-        "Print BIOS name, version, release date, etc",
-        ffParseBiosCommandOptions,
-        ffParseBiosJsonObject,
-        ffPrintBios,
-        ffGenerateBiosJsonResult,
-        ffPrintBiosHelpFormat,
-        ffGenerateBiosJsonConfig
-    );
-    ffOptionInitModuleArg(&options->moduleArgs);
+    ffOptionInitModuleArg(&options->moduleArgs, "");
 }
 
 void ffDestroyBiosOptions(FFBiosOptions* options)
 {
     ffOptionDestroyModuleArg(&options->moduleArgs);
 }
+
+FFModuleBaseInfo ffBiosModuleInfo = {
+    .name = FF_BIOS_MODULE_NAME,
+    .description = "Print information of 1st-stage bootloader (name, version, release date, etc)",
+    .initOptions = (void*) ffInitBiosOptions,
+    .destroyOptions = (void*) ffDestroyBiosOptions,
+    .parseJsonObject = (void*) ffParseBiosJsonObject,
+    .printModule = (void*) ffPrintBios,
+    .generateJsonResult = (void*) ffGenerateBiosJsonResult,
+    .generateJsonConfig = (void*) ffGenerateBiosJsonConfig,
+    .formatArgs = FF_FORMAT_ARG_LIST(((FFModuleFormatArg[]) {
+        {"Bios date", "date"},
+        {"Bios release", "release"},
+        {"Bios vendor", "vendor"},
+        {"Bios version", "version"},
+        {"Firmware type", "type"},
+    }))
+};
