@@ -4,10 +4,10 @@
 #include "modules/chassis/chassis.h"
 #include "util/stringUtils.h"
 
-#define FF_CHASSIS_NUM_FORMAT_ARGS 4
-
-void ffPrintChassis(FFChassisOptions* options)
+bool ffPrintChassis(FFChassisOptions* options)
 {
+    bool success = false;
+
     FFChassisResult result;
     ffStrbufInit(&result.type);
     ffStrbufInit(&result.vendor);
@@ -38,58 +38,44 @@ void ffPrintChassis(FFChassisOptions* options)
     }
     else
     {
-        FF_PRINT_FORMAT_CHECKED(FF_CHASSIS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_CHASSIS_NUM_FORMAT_ARGS, ((FFformatarg[]) {
+        FF_PRINT_FORMAT_CHECKED(FF_CHASSIS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, ((FFformatarg[]) {
             FF_FORMAT_ARG(result.type, "type"),
             FF_FORMAT_ARG(result.vendor, "vendor"),
             FF_FORMAT_ARG(result.version, "version"),
             FF_FORMAT_ARG(result.serial, "serial"),
         }));
     }
+    success = true;
 
 exit:
     ffStrbufDestroy(&result.type);
     ffStrbufDestroy(&result.vendor);
     ffStrbufDestroy(&result.version);
     ffStrbufDestroy(&result.serial);
-}
-
-bool ffParseChassisCommandOptions(FFChassisOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_CHASSIS_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    return false;
+    return success;
 }
 
 void ffParseChassisJsonObject(FFChassisOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        ffPrintError(FF_CHASSIS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_CHASSIS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateChassisJsonConfig(FFChassisOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyChassisOptions))) FFChassisOptions defaultOptions;
-    ffInitChassisOptions(&defaultOptions);
-
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 }
 
-void ffGenerateChassisJsonResult(FF_MAYBE_UNUSED FFChassisOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateChassisJsonResult(FF_MAYBE_UNUSED FFChassisOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
+    bool success = false;
     FFChassisResult result;
     ffStrbufInit(&result.type);
     ffStrbufInit(&result.vendor);
@@ -115,37 +101,18 @@ void ffGenerateChassisJsonResult(FF_MAYBE_UNUSED FFChassisOptions* options, yyjs
     yyjson_mut_obj_add_strbuf(doc, obj, "vendor", &result.vendor);
     yyjson_mut_obj_add_strbuf(doc, obj, "version", &result.version);
     yyjson_mut_obj_add_strbuf(doc, obj, "serial", &result.serial);
+    success = true;
 
 exit:
     ffStrbufDestroy(&result.type);
     ffStrbufDestroy(&result.vendor);
     ffStrbufDestroy(&result.version);
     ffStrbufDestroy(&result.serial);
-}
-
-void ffPrintChassisHelpFormat(void)
-{
-    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_CHASSIS_MODULE_NAME, "{1}", FF_CHASSIS_NUM_FORMAT_ARGS, ((const char* []) {
-        "chassis type - type",
-        "chassis vendor - vendor",
-        "chassis version - version",
-        "chassis serial number - serial",
-    }));
+    return success;
 }
 
 void ffInitChassisOptions(FFChassisOptions* options)
 {
-    ffOptionInitModuleBaseInfo(
-        &options->moduleInfo,
-        FF_CHASSIS_MODULE_NAME,
-        "Print chassis type (desktop, laptop, etc)",
-        ffParseChassisCommandOptions,
-        ffParseChassisJsonObject,
-        ffPrintChassis,
-        ffGenerateChassisJsonResult,
-        ffPrintChassisHelpFormat,
-        ffGenerateChassisJsonConfig
-    );
     ffOptionInitModuleArg(&options->moduleArgs, "");
 }
 
@@ -153,3 +120,20 @@ void ffDestroyChassisOptions(FFChassisOptions* options)
 {
     ffOptionDestroyModuleArg(&options->moduleArgs);
 }
+
+FFModuleBaseInfo ffChassisModuleInfo = {
+    .name = FF_CHASSIS_MODULE_NAME,
+    .description = "Print chassis type (desktop, laptop, etc)",
+    .initOptions = (void*) ffInitChassisOptions,
+    .destroyOptions = (void*) ffDestroyChassisOptions,
+    .parseJsonObject = (void*) ffParseChassisJsonObject,
+    .printModule = (void*) ffPrintChassis,
+    .generateJsonResult = (void*) ffGenerateChassisJsonResult,
+    .generateJsonConfig = (void*) ffGenerateChassisJsonConfig,
+    .formatArgs = FF_FORMAT_ARG_LIST(((FFModuleFormatArg[]) {
+        {"Chassis type", "type"},
+        {"Chassis vendor", "vendor"},
+        {"Chassis version", "version"},
+        {"Chassis serial number", "serial"},
+    })),
+};
