@@ -2,6 +2,7 @@
 #include "common/jsonconfig.h"
 #include "common/parsing.h"
 #include "common/temps.h"
+#include "common/frequency.h"
 #include "detection/cpu/cpu.h"
 #include "modules/cpu/cpu.h"
 #include "util/stringUtils.h"
@@ -11,8 +12,9 @@ static int sortCores(const FFCPUCore* a, const FFCPUCore* b)
     return (int)b->freq - (int)a->freq;
 }
 
-void ffPrintCPU(FFCPUOptions* options)
+bool ffPrintCPU(FFCPUOptions* options)
 {
+    bool success = false;
     FFCPUResult cpu = {
         .temperature = FF_CPU_TEMP_UNSET,
         .frequencyMax = 0,
@@ -77,10 +79,10 @@ void ffPrintCPU(FFCPUOptions* options)
             if(freq > 0)
             {
                 ffStrbufAppendS(&str, " @ ");
-                ffParseFrequency(freq, &str);
+                ffFreqAppendNum(freq, &str);
             }
 
-            if(cpu.temperature == cpu.temperature) //FF_CPU_TEMP_UNSET
+            if(cpu.temperature != FF_CPU_TEMP_UNSET)
             {
                 ffStrbufAppendS(&str, " - ");
                 ffTempsAppendNum(cpu.temperature, &str, options->tempConfig, &options->moduleArgs);
@@ -91,9 +93,9 @@ void ffPrintCPU(FFCPUOptions* options)
         else
         {
             FF_STRBUF_AUTO_DESTROY freqBase = ffStrbufCreate();
-            ffParseFrequency(cpu.frequencyBase, &freqBase);
+            ffFreqAppendNum(cpu.frequencyBase, &freqBase);
             FF_STRBUF_AUTO_DESTROY freqMax = ffStrbufCreate();
-            ffParseFrequency(cpu.frequencyMax, &freqMax);
+            ffFreqAppendNum(cpu.frequencyMax, &freqMax);
 
             FF_STRBUF_AUTO_DESTROY tempStr = ffStrbufCreate();
             ffTempsAppendNum(cpu.temperature, &tempStr, options->tempConfig, &options->moduleArgs);
@@ -108,80 +110,58 @@ void ffPrintCPU(FFCPUOptions* options)
                 FF_FORMAT_ARG(tempStr, "temperature"),
                 FF_FORMAT_ARG(coreTypes, "core-types"),
                 FF_FORMAT_ARG(cpu.packages, "packages"),
+                FF_FORMAT_ARG(cpu.march, "march"),
             }));
         }
+        success = true;
     }
 
     ffStrbufDestroy(&cpu.name);
     ffStrbufDestroy(&cpu.vendor);
-}
 
-bool ffParseCPUCommandOptions(FFCPUOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_CPU_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    if (ffTempsParseCommandOptions(key, subKey, value, &options->temp, &options->tempConfig))
-        return true;
-
-    if (ffStrEqualsIgnCase(subKey, "show-pe-core-count"))
-    {
-        options->showPeCoreCount = ffOptionParseBoolean(value);
-        return true;
-    }
-
-    return false;
+    return success;
 }
 
 void ffParseCPUJsonObject(FFCPUOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
         if (ffTempsParseJsonObject(key, val, &options->temp, &options->tempConfig))
             continue;
 
-        if (ffStrEqualsIgnCase(key, "freqNdigits"))
+        if (unsafe_yyjson_equals_str(key, "freqNdigits"))
         {
             ffPrintError(FF_CPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "modules.CPU.freqNdigits has been moved to display.freq.ndigits");
             continue;
         }
 
-        if (ffStrEqualsIgnCase(key, "showPeCoreCount"))
+        if (unsafe_yyjson_equals_str(key, "showPeCoreCount"))
         {
             options->showPeCoreCount = yyjson_get_bool(val);
             continue;
         }
 
-        ffPrintError(FF_CPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_CPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateCPUJsonConfig(FFCPUOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyCPUOptions))) FFCPUOptions defaultOptions;
-    ffInitCPUOptions(&defaultOptions);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    ffTempsGenerateJsonConfig(doc, module, options->temp, options->tempConfig);
 
-    ffTempsGenerateJsonConfig(doc, module, defaultOptions.temp, defaultOptions.tempConfig, options->temp, options->tempConfig);
-
-    if (defaultOptions.showPeCoreCount != options->showPeCoreCount)
-        yyjson_mut_obj_add_bool(doc, module, "showPeCoreCount", options->showPeCoreCount);
+    yyjson_mut_obj_add_bool(doc, module, "showPeCoreCount", options->showPeCoreCount);
 }
 
-void ffGenerateCPUJsonResult(FFCPUOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateCPUJsonResult(FFCPUOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
+    bool success = false;
     FFCPUResult cpu = {
         .temperature = FF_CPU_TEMP_UNSET,
         .frequencyMax = 0,
@@ -227,17 +207,43 @@ void ffGenerateCPUJsonResult(FFCPUOptions* options, yyjson_mut_doc* doc, yyjson_
             yyjson_mut_obj_add_uint(doc, core, "freq", cpu.coreTypes[i].freq);
         }
 
-        yyjson_mut_obj_add_real(doc, obj, "temperature", cpu.temperature);
+        if (cpu.temperature != FF_CPU_TEMP_UNSET)
+            yyjson_mut_obj_add_real(doc, obj, "temperature", cpu.temperature);
+        else
+            yyjson_mut_obj_add_null(doc, obj, "temperature");
+
+        if (cpu.march)
+            yyjson_mut_obj_add_str(doc, obj, "march", cpu.march);
+        else
+            yyjson_mut_obj_add_null(doc, obj, "march");
+
+        success = true;
     }
 
     ffStrbufDestroy(&cpu.name);
     ffStrbufDestroy(&cpu.vendor);
+
+    return success;
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
+void ffInitCPUOptions(FFCPUOptions* options)
+{
+    ffOptionInitModuleArg(&options->moduleArgs, "");
+    options->temp = false;
+    options->tempConfig = (FFColorRangeConfig) { 60, 80 };
+    options->showPeCoreCount = false;
+}
+
+void ffDestroyCPUOptions(FFCPUOptions* options)
+{
+    ffOptionDestroyModuleArg(&options->moduleArgs);
+}
+
+FFModuleBaseInfo ffCPUModuleInfo = {
     .name = FF_CPU_MODULE_NAME,
     .description = "Print CPU name, frequency, etc",
-    .parseCommandOptions = (void*) ffParseCPUCommandOptions,
+    .initOptions = (void*) ffInitCPUOptions,
+    .destroyOptions = (void*) ffDestroyCPUOptions,
     .parseJsonObject = (void*) ffParseCPUJsonObject,
     .printModule = (void*) ffPrintCPU,
     .generateJsonResult = (void*) ffGenerateCPUJsonResult,
@@ -253,19 +259,6 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Temperature (formatted)", "temperature"},
         {"Logical core count grouped by frequency", "core-types"},
         {"Processor package count", "packages"},
+        {"X86-64 CPU microarchitecture", "march"},
     }))
 };
-
-void ffInitCPUOptions(FFCPUOptions* options)
-{
-    options->moduleInfo = ffModuleInfo;
-    ffOptionInitModuleArg(&options->moduleArgs, "");
-    options->temp = false;
-    options->tempConfig = (FFColorRangeConfig) { 60, 80 };
-    options->showPeCoreCount = false;
-}
-
-void ffDestroyCPUOptions(FFCPUOptions* options)
-{
-    ffOptionDestroyModuleArg(&options->moduleArgs);
-}
