@@ -4,7 +4,7 @@
 
 #define FF_WMTHEME_MODULE_NAME "WMTheme"
 
-void ffPrintWMTheme(FFWMThemeOptions* options);
+bool ffPrintWMTheme(FFWMThemeOptions* options);
 void ffInitWMThemeOptions(FFWMThemeOptions* options);
 void ffDestroyWMThemeOptions(FFWMThemeOptions* options);
 
